summaryrefslogtreecommitdiffstats
path: root/lib/systemd.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/systemd.h')
-rw-r--r--lib/systemd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/systemd.h b/lib/systemd.h
index c8fb328ad..ba2461b8a 100644
--- a/lib/systemd.h
+++ b/lib/systemd.h
@@ -21,11 +21,11 @@ extern bool sd_stderr_is_journal;
void systemd_send_stopping(void);
/*
* master - The struct event_master * to use to schedule ourself
* the_process - Should we send watchdog if we are not the requested
* process?
*/
-void systemd_send_started(struct event_master *master);
+void systemd_send_started(struct event_loop *master);
/*
* status - A status string to send to systemd
@@ -21,11 +21,11 @@ extern bool sd_stderr_is_journal;
void systemd_send_stopping(void);
/*
- * master - The struct event_master * to use to schedule ourself
+ * master - The struct event_loop * to use to schedule ourself
* the_process - Should we send watchdog if we are not the requested
* process?